# autoteachable

A simple teachable chat, built on [AutoGen framework](https://microsoft.github.io/autogen/docs/Getting-Started/).

It is a simplified version of the autoteachable, integrated in our [LetMeDoIt AI project](https://github.com/eliranwong/letmedoit)

# Install

> pip install autoteachable

# Usage

> autoteachable
